==> jaxrs-ri-2.2-src.tar.bz2: jaxrs-ri/src/org/glassfish/jersey/server/BroadcasterListener.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.jersey.server;

/**
 * Listener interface that can be implemented to listen to events fired by {@link Broadcaster} object.
 *
 * To listen to events, implementation of this interface needs to register with a particular {@link Broadcaster} instance
 * using {@link Broadcaster#addBroadcasterListener(BroadcasterListener)}.
 *
 * @author Martin Matula (martin.matula at oracle.com)
 */
public interface BroadcasterListener<T> {
    /**
     * Called when exception was thrown by a given chunked response when trying to write to it or close it.
     * @param chunkedOutput instance that threw exception
     * @param exception thrown exception
     */
    void onException(ChunkedOutput<T> chunkedOutput, Exception exception);

    /**
     * Called when the chunkedOutput has been closed (either by client closing the connection or by calling
     * {@link ChunkedOutput#close()} on the server side.
     *
     * @param chunkedOutput instance that has been closed.
     */
    void onClose(ChunkedOutput<T> chunkedOutput);
}

==> jaxrs-ri-2.9-src.tar.bz2: jaxrs-ri/src/org/glassfish/jersey/server/BroadcasterListener.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2012-2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.jersey.server;

/**
 * Listener interface that can be implemented to listen to events fired by {@link Broadcaster} object.
 *
 * To listen to events, implementation of this interface needs to register with a particular {@link Broadcaster} instance
 * using {@link Broadcaster#add(BroadcasterListener)}.
 *
 * @author Martin Matula (martin.matula at oracle.com)
 */
public interface BroadcasterListener<T> {
    /**
     * Called when exception was thrown by a given chunked response when trying to write to it or close it.
     * @param chunkedOutput instance that threw exception
     * @param exception thrown exception
     */
    void onException(ChunkedOutput<T> chunkedOutput, Exception exception);

    /**
     * Called when the chunkedOutput has been closed (either by client closing the connection or by calling
     * {@link ChunkedOutput#close()} on the server side.
     *
     * @param chunkedOutput instance that has been closed.
     */
    void onClose(ChunkedOutput<T> chunkedOutput);
}
